@@ -1,12 +1,13 @@
 import time
 from asyncio import get_event_loop
+import logging
 from typing import Optional
 
 from .. import util, create_irc
 from ..channel import Channel, channels
 from ..command import Command, commands, CustomCommandAction, is_command_on_cooldown, get_time_since_execute, \
     update_command_last_execute
-from ..config import cfg
+from ..config import cfg, get_nick
 from ..database import get_custom_command
 from ..disabled_commands import is_command_disabled
 from ..emote import update_global_emotes
@@ -21,6 +22,7 @@ from ..permission import perms
 from ..modloader import Mod
 from ..shared import set_bot
 from ..config import init_config
+from ..modloader import mods
 
 
 # noinspection PyMethodMayBeStatic
@@ -147,7 +149,7 @@ class BaseBot:
 
     async def _connect(self):
         """connects to twitch, sends auth info, and joins the channels in the config"""
-        print(f'logging in as {cfg.nick}')
+        print(f'logging in as {get_nick()}')
 
         util.send_auth(self.irc)
         self._request_permissions()
@@ -259,7 +261,7 @@ class BaseBot:
 
             coro = mod_coro = event_coro = None
             cmd: Command = (await self.get_command_from_msg(msg)
-                            if msg.is_user_message and msg.author != cfg.nick
+                            if msg.is_user_message and msg.author != get_nick()
                             else None)
 
             if cmd and ((msg.is_whisper and cmd.context & CommandContext.WHISPER)
@@ -282,7 +284,7 @@ class BaseBot:
 
             elif msg.type is MessageType.USER_JOIN:
                 # the bot has joined a channel
-                if msg.author == cfg.nick:
+                if msg.author == get_nick():
                     coro = self.on_channel_joined(msg.channel)
                     mod_coro = trigger_mod_event(Event.on_channel_joined, msg.channel, channel=msg.channel_name)
                     event_coro = trigger_event(Event.on_channel_joined, msg.channel)
@@ -322,3 +324,13 @@ class BaseBot:
 
             if event_coro is not None:
                 get_event_loop().create_task(event_coro)
+
+        for mod in mods.values():
+            # notify all mods of being unloaded,
+            # this is put in a try/except
+            # so that any exceptions raised from unloaded overrides will not cancel unloading the others
+            try:
+                await mod.unloaded()
+            except Exception as e:
+                print(f'\nwhen unloading mod "{mod.name}" this exception occurred:\n')
+                logging.exception(e)
